api.system.components.runtime.v1.property package — Argus-Toolbelt 1.0 documentation

# api.system.components.runtime.v1.property package

## Submodules

## api.system.components.runtime.v1.property.property module

Autogenerated API

`api.system.components.runtime.v1.property.property.` `get_properties`(property: str, type: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch property from runtime components (INTERNAL)

  Return type: | `dict`
  Parameters: | property (str) – Property to fetch type (str) –
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {}

## Module contents